audiofile
=========

.. automodule:: audiofile

read
----

.. autofunction:: read

write
-----

.. autofunction:: write

channels
--------

.. autofunction:: channels

duration
--------

.. autofunction:: duration

samples
-------

.. autofunction:: samples

sampling_rate
-------------

.. autofunction:: sampling_rate

convert_to_wav
--------------

.. autofunction:: convert_to_wav
